@@ -9,22 +9,18 @@ describe 'redis-cli task' do
 
   let(:task_name) { 'redis::redis_cli' }
 
-  it 'install redis-cli with the class' do
-    pp = <<-EOS
-    include redis
-    EOS
+  if bolt_supported?
+    include_examples 'an idempotent resource' do
+      let(:manifest) { 'include redis' }
+    end
 
-    apply_manifest(pp, catch_failures: true)
-    apply_manifest(pp, catch_changes: true)
-  end
-
-  unless fact('os.family') == 'RedHat' && fact('os.release.major').to_i >= 9
     describe 'ping' do
       let(:params) { 'command="ping"' }
 
       it 'execute ping' do
-        is_expected.to match(%r{{\s*"status":\s*"PONG"\s*}})
-        is_expected.to match(%r{Ran on 1 target in .+ sec})
+        is_expected.
+          to match(%r{{\s*"status":\s*"PONG"\s*}}).
+          and match(%r{Ran on 1 target in .+ sec})
       end
     end
 
@@ -33,8 +29,9 @@ describe 'redis-cli task' do
         let(:params) { 'command="ping; cat /etc/passwd"' }
 
         it 'stops script injections and escapes' do
-          is_expected.to match(%r!{\s*"status":\s*"ERR unknown command ('|`)ping; cat /etc/passwd('|`)!)
-          is_expected.to match(%r{Ran on 1 target in .+ sec})
+          is_expected.
+            to match(%r!{\s*"status":\s*"ERR unknown command ('|`)ping; cat /etc/passwd('|`)!).
+            and match(%r{Ran on 1 target in .+ sec})
         end
       end
 
@@ -42,8 +39,9 @@ describe 'redis-cli task' do
         let(:params) { 'command="ping && cat /etc/passwd"' }
 
         it 'stops script injections and escapes' do
-          is_expected.to match(%r!{\s*"status":\s*"ERR unknown command ('|`)ping && cat /etc/passwd('|`)!)
-          is_expected.to match(%r{Ran on 1 target in .+ sec})
+          is_expected.
+            to match(%r!{\s*"status":\s*"ERR unknown command ('|`)ping && cat /etc/passwd('|`)!).
+            and match(%r{Ran on 1 target in .+ sec})
         end
       end
     end
